/* Jalview - a java multiple alignment editor
 * Copyright (C) 1998  Michele Clamp
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package jalview.io;

import jalview.datamodel.*;

import java.io.*;
import java.util.*;
import java.net.*;
import java.awt.Font;

public class BLCFile extends AlignFile {

  Vector titles;

  public BLCFile()
  {}

  public BLCFile(String inStr) {
    super(inStr);
  }

  public void initData() {
    super.initData();
    titles = new Vector();
  }

  public BLCFile(String inFile, String type) throws IOException {
    super(inFile,type);
  }


  public void parse()
  {
    boolean idsFound=false;
    Vector ids = new Vector();
    StringBuffer seqstrings [];
    Vector starts = new Vector();
    Vector ends = new Vector();

   String line=null;
   try{
     do{
      line = nextLine();

      // seek end of ids
      if (line.indexOf("*") > -1)
      {
        idsFound=true;
        break;
      }

      int abracket = line.indexOf(">");

      if (abracket > -1)
      {

        if(line.indexOf(" ")>-1)
        {
          ids.addElement(line.substring(abracket+1, line.indexOf(" ", abracket+1)));
          starts.addElement("0");
          ends.addElement("0");
        }
        else
        {
          ids.addElement( line.substring(abracket + 1, line.indexOf("/")));
          line = line.substring(line.indexOf("/") + 1);
          starts.addElement(line.substring(0, line.indexOf("-")));
          ends.addElement(line.substring(line.indexOf("-") + 1));
        }
      }
    }while(!idsFound);

    int starCol = line.indexOf("*");
    seqstrings = new StringBuffer[ids.size()];
    for(int i=0; i<ids.size(); i++)
    {
      if(seqstrings[i]==null)
        seqstrings[i] = new StringBuffer();
    }

    while ((line = nextLine()).indexOf("*")==-1)
    {
      for(int i=0; i<ids.size(); i++)
      {
        if(line.length()>i+starCol)
          seqstrings[i].append(line.charAt(i + starCol));
      }
    }

    for(int i=0; i<ids.size(); i++)
    {
      Sequence newSeq = new Sequence(ids.elementAt(i).toString(),
                                     seqstrings[i].toString(),
                                     Integer.parseInt(starts.elementAt(i).toString()),
                                     Integer.parseInt(ends.elementAt(i).toString()));
      seqs.addElement(newSeq);
    }

   }catch(Exception ex){ex.printStackTrace();}
  }

  public String print() {
    return print(getSeqsAsArray());
  }
  public static String print(SequenceI[] s) {
    StringBuffer out = new StringBuffer();

    int i=0;
    int max = -1;
    while (i < s.length && s[i] != null) {
      out.append(">" + s[i].getName() + "/" + s[i].getStart() + "-" + s[i].getEnd() + "\n");
      if (s[i].getSequence().length() > max) { max = s[i].getSequence().length();}
      i++;
    }

      out.append("* iteration 1\n");
      for (int j = 0; j < max; j++) {
        i=0;
        while (i < s.length && s[i] != null) {
          if(s[i].getSequence().length()>j )
            out.append(s[i].getSequence().substring(j,j+1));
          else
            out.append("-");
          i++;
        }
        out.append("\n");
      }
    out.append("*\n");
    return out.toString();

  }
}
